# Open Peer Power Frontend

This is the repository for the official [Open Peer Power](https://openpeerpower.io) frontend.

[![Screenshot of the frontend](https://raw.githubusercontent.com/openpeerpower/openpeerpower-polymer/master/docs/screenshot.png)](https://demo.openpeerpower.io/)

- [View demo of Open Peer Power](https://demo.openpeerpower.io/)
- [More information about Open Peer Power](https://openpeerpower.io)
- [Frontend development instructions](https://developers.openpeerpower.io/docs/frontend/development/)

## Development

- Initial setup: `script/setup`
- Development: [Instructions](https://developers.openpeerpower.io/docs/frontend/development/)
- Production build: `script/build_frontend`
- Gallery: `cd gallery && script/develop_gallery`
- Supervisor: [Instructions](https://developers.openpeerpower.io/docs/supervisor/developing)

## Frontend development

### Classic environment

A complete guide can be found at the following [link](https://www.openpeerpower.io/developers/frontend/). It describes a short guide for the build of project.

## License

Open Peer Power is open-source and Apache 2 licensed. Feel free to browse the repository, learn and reuse parts in your own projects.

We use [BrowserStack](https://www.browserstack.com) to test Open Peer Power on a large variety of devices.
